<?php

namespace Litecms\Rank\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Rank\Models\Rank;

class RankPolicy
{

    /**
     * Determine if the given user can view the rank.
     *
     * @param UserPolicy $user
     * @param Rank $rank
     *
     * @return bool
     */
    public function view(UserPolicy $user, Rank $rank)
    {
        if ($user->canDo('rank.rank.view') && $user->isAdmin()) {
            return true;
        }

        return $rank->user_id == user_id() && $rank->user_type == user_type();
    }

    /**
     * Determine if the given user can create a rank.
     *
     * @param UserPolicy $user
     * @param Rank $rank
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('rank.rank.create');
    }

    /**
     * Determine if the given user can update the given rank.
     *
     * @param UserPolicy $user
     * @param Rank $rank
     *
     * @return bool
     */
    public function update(UserPolicy $user, Rank $rank)
    {
        if ($user->canDo('rank.rank.edit') && $user->isAdmin()) {
            return true;
        }

        return $rank->user_id == user_id() && $rank->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given rank.
     *
     * @param UserPolicy $user
     * @param Rank $rank
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Rank $rank)
    {
        return $rank->user_id == user_id() && $rank->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given rank.
     *
     * @param UserPolicy $user
     * @param Rank $rank
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Rank $rank)
    {
        if ($user->canDo('rank.rank.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given rank.
     *
     * @param UserPolicy $user
     * @param Rank $rank
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Rank $rank)
    {
        if ($user->canDo('rank.rank.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
